@@ -15,6 +15,7 @@
 import copy
 import re
 from concurrent import futures
+import warnings
 
 import mock
 import pytest
@@ -36,9 +37,9 @@ from google.api_core import exceptions
 import google.auth.credentials
 
 try:
-    from google.cloud import bigquery_storage_v1beta1
+    from google.cloud import bigquery_storage_v1
 except ImportError:  # pragma: NO COVER
-    bigquery_storage_v1beta1 = None
+    bigquery_storage_v1 = None
 from google.cloud import bigquery
 from google.cloud.bigquery import job
 from google.cloud.bigquery import table
@@ -74,8 +75,8 @@ def missing_bq_storage():
 
     def fail_if(name, globals, locals, fromlist, level):
         # NOTE: *very* simplified, assuming a straightforward absolute import
-        return "bigquery_storage_v1beta1" in name or (
-            fromlist is not None and "bigquery_storage_v1beta1" in fromlist
+        return "bigquery_storage_v1" in name or (
+            fromlist is not None and "bigquery_storage_v1" in fromlist
         )
 
     return maybe_fail_import(predicate=fail_if)
@@ -305,14 +306,14 @@ def test__make_bqstorage_client_false():
 
 
 @pytest.mark.skipif(
-    bigquery_storage_v1beta1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 def test__make_bqstorage_client_true():
     credentials_mock = mock.create_autospec(
         google.auth.credentials.Credentials, instance=True
     )
     got = magics._make_bqstorage_client(True, credentials_mock)
-    assert isinstance(got, bigquery_storage_v1beta1.BigQueryStorageClient)
+    assert isinstance(got, bigquery_storage_v1.BigQueryReadClient)
 
 
 def test__make_bqstorage_client_true_raises_import_error(missing_bq_storage):
@@ -329,7 +330,7 @@ def test__make_bqstorage_client_true_raises_import_error(missing_bq_storage):
 
 
 @pytest.mark.skipif(
-    bigquery_storage_v1beta1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 @pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
 def test__make_bqstorage_client_true_missing_gapic(missing_grpcio_lib):
@@ -386,13 +387,31 @@ def test_extension_load():
 
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
-def test_bigquery_magic_without_optional_arguments(missing_bq_storage):
+@pytest.mark.skipif(
+    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
+)
+def test_bigquery_magic_without_optional_arguments(monkeypatch):
     ip = IPython.get_ipython()
     ip.extension_manager.load_extension("google.cloud.bigquery")
-    magics.context.credentials = mock.create_autospec(
+    mock_credentials = mock.create_autospec(
         google.auth.credentials.Credentials, instance=True
     )
 
+    # Set up the context with monkeypatch so that it's reset for subsequent
+    # tests.
+    monkeypatch.setattr(magics.context, "credentials", mock_credentials)
+
+    # Mock out the BigQuery Storage API.
+    bqstorage_mock = mock.create_autospec(bigquery_storage_v1.BigQueryReadClient)
+    bqstorage_instance_mock = mock.create_autospec(
+        bigquery_storage_v1.BigQueryReadClient, instance=True
+    )
+    bqstorage_instance_mock.transport = mock.Mock()
+    bqstorage_mock.return_value = bqstorage_instance_mock
+    bqstorage_client_patch = mock.patch(
+        "google.cloud.bigquery_storage_v1.BigQueryReadClient", bqstorage_mock
+    )
+
     sql = "SELECT 17 AS num"
     result = pandas.DataFrame([17], columns=["num"])
     run_query_patch = mock.patch(
@@ -403,11 +422,11 @@ def test_bigquery_magic_without_optional_arguments(missing_bq_storage):
     )
     query_job_mock.to_dataframe.return_value = result
 
-    # Shouldn't fail when BigQuery Storage client isn't installed.
-    with run_query_patch as run_query_mock, missing_bq_storage:
+    with run_query_patch as run_query_mock, bqstorage_client_patch:
         run_query_mock.return_value = query_job_mock
         return_value = ip.run_cell_magic("bigquery", "", sql)
 
+    assert bqstorage_mock.called  # BQ storage client was used
     assert isinstance(return_value, pandas.DataFrame)
     assert len(return_value) == len(result)  # verify row count
     assert list(return_value) == list(result)  # verify column names
@@ -530,7 +549,7 @@ def test_bigquery_magic_clears_display_in_verbose_mode():
 
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(
-    bigquery_storage_v1beta1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 def test_bigquery_magic_with_bqstorage_from_argument(monkeypatch):
     ip = IPython.get_ipython()
@@ -542,19 +561,16 @@ def test_bigquery_magic_with_bqstorage_from_argument(monkeypatch):
     # Set up the context with monkeypatch so that it's reset for subsequent
     # tests.
     monkeypatch.setattr(magics.context, "credentials", mock_credentials)
-    monkeypatch.setattr(magics.context, "use_bqstorage_api", False)
 
     # Mock out the BigQuery Storage API.
-    bqstorage_mock = mock.create_autospec(
-        bigquery_storage_v1beta1.BigQueryStorageClient
-    )
+    bqstorage_mock = mock.create_autospec(bigquery_storage_v1.BigQueryReadClient)
     bqstorage_instance_mock = mock.create_autospec(
-        bigquery_storage_v1beta1.BigQueryStorageClient, instance=True
+        bigquery_storage_v1.BigQueryReadClient, instance=True
     )
     bqstorage_instance_mock.transport = mock.Mock()
     bqstorage_mock.return_value = bqstorage_instance_mock
     bqstorage_client_patch = mock.patch(
-        "google.cloud.bigquery_storage_v1beta1.BigQueryStorageClient", bqstorage_mock
+        "google.cloud.bigquery_storage_v1.BigQueryReadClient", bqstorage_mock
     )
 
     sql = "SELECT 17 AS num"
@@ -566,67 +582,20 @@ def test_bigquery_magic_with_bqstorage_from_argument(monkeypatch):
         google.cloud.bigquery.job.QueryJob, instance=True
     )
     query_job_mock.to_dataframe.return_value = result
-    with run_query_patch as run_query_mock, bqstorage_client_patch:
+    with run_query_patch as run_query_mock, bqstorage_client_patch, warnings.catch_warnings(
+        record=True
+    ) as warned:
         run_query_mock.return_value = query_job_mock
 
         return_value = ip.run_cell_magic("bigquery", "--use_bqstorage_api", sql)
 
-    assert len(bqstorage_mock.call_args_list) == 1
-    kwargs = bqstorage_mock.call_args_list[0].kwargs
-    assert kwargs.get("credentials") is mock_credentials
-    client_info = kwargs.get("client_info")
-    assert client_info is not None
-    assert client_info.user_agent == "ipython-" + IPython.__version__
+    # Deprecation warning should have been issued.
+    def warning_match(warning):
+        message = str(warning).lower()
+        return "deprecated" in message and "use_bqstorage_api" in message
 
-    query_job_mock.to_dataframe.assert_called_once_with(
-        bqstorage_client=bqstorage_instance_mock
-    )
-
-    assert isinstance(return_value, pandas.DataFrame)
-
-
-@pytest.mark.usefixtures("ipython_interactive")
-@pytest.mark.skipif(
-    bigquery_storage_v1beta1 is None, reason="Requires `google-cloud-bigquery-storage`"
-)
-def test_bigquery_magic_with_bqstorage_from_context(monkeypatch):
-    ip = IPython.get_ipython()
-    ip.extension_manager.load_extension("google.cloud.bigquery")
-    mock_credentials = mock.create_autospec(
-        google.auth.credentials.Credentials, instance=True
-    )
-
-    # Set up the context with monkeypatch so that it's reset for subsequent
-    # tests.
-    monkeypatch.setattr(magics.context, "credentials", mock_credentials)
-    monkeypatch.setattr(magics.context, "use_bqstorage_api", True)
-
-    # Mock out the BigQuery Storage API.
-    bqstorage_mock = mock.create_autospec(
-        bigquery_storage_v1beta1.BigQueryStorageClient
-    )
-    bqstorage_instance_mock = mock.create_autospec(
-        bigquery_storage_v1beta1.BigQueryStorageClient, instance=True
-    )
-    bqstorage_instance_mock.transport = mock.Mock()
-    bqstorage_mock.return_value = bqstorage_instance_mock
-    bqstorage_client_patch = mock.patch(
-        "google.cloud.bigquery_storage_v1beta1.BigQueryStorageClient", bqstorage_mock
-    )
-
-    sql = "SELECT 17 AS num"
-    result = pandas.DataFrame([17], columns=["num"])
-    run_query_patch = mock.patch(
-        "google.cloud.bigquery.magics._run_query", autospec=True
-    )
-    query_job_mock = mock.create_autospec(
-        google.cloud.bigquery.job.QueryJob, instance=True
-    )
-    query_job_mock.to_dataframe.return_value = result
-    with run_query_patch as run_query_mock, bqstorage_client_patch:
-        run_query_mock.return_value = query_job_mock
-
-        return_value = ip.run_cell_magic("bigquery", "", sql)
+    expected_warnings = list(filter(warning_match, warned))
+    assert len(expected_warnings) == 1
 
     assert len(bqstorage_mock.call_args_list) == 1
     kwargs = bqstorage_mock.call_args_list[0].kwargs
@@ -644,9 +613,9 @@ def test_bigquery_magic_with_bqstorage_from_context(monkeypatch):
 
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(
-    bigquery_storage_v1beta1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
 )
-def test_bigquery_magic_without_bqstorage(monkeypatch):
+def test_bigquery_magic_with_rest_client_requested(monkeypatch):
     ip = IPython.get_ipython()
     ip.extension_manager.load_extension("google.cloud.bigquery")
     mock_credentials = mock.create_autospec(
@@ -658,11 +627,9 @@ def test_bigquery_magic_without_bqstorage(monkeypatch):
     monkeypatch.setattr(magics.context, "credentials", mock_credentials)
 
     # Mock out the BigQuery Storage API.
-    bqstorage_mock = mock.create_autospec(
-        bigquery_storage_v1beta1.BigQueryStorageClient
-    )
+    bqstorage_mock = mock.create_autospec(bigquery_storage_v1.BigQueryReadClient)
     bqstorage_client_patch = mock.patch(
-        "google.cloud.bigquery_storage_v1beta1.BigQueryStorageClient", bqstorage_mock
+        "google.cloud.bigquery_storage_v1.BigQueryReadClient", bqstorage_mock
     )
 
     sql = "SELECT 17 AS num"
@@ -677,7 +644,7 @@ def test_bigquery_magic_without_bqstorage(monkeypatch):
     with run_query_patch as run_query_mock, bqstorage_client_patch:
         run_query_mock.return_value = query_job_mock
 
-        return_value = ip.run_cell_magic("bigquery", "", sql)
+        return_value = ip.run_cell_magic("bigquery", "--use_rest_api", sql)
 
         bqstorage_mock.assert_not_called()
         query_job_mock.to_dataframe.assert_called_once_with(bqstorage_client=None)
@@ -855,7 +822,7 @@ def test_bigquery_magic_w_table_id_and_destination_var():
 
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(
-    bigquery_storage_v1beta1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 @pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
 def test_bigquery_magic_w_table_id_and_bqstorage_client():
@@ -878,16 +845,14 @@ def test_bigquery_magic_w_table_id_and_bqstorage_client():
         "google.cloud.bigquery.magics.bigquery.Client", autospec=True
     )
 
-    bqstorage_mock = mock.create_autospec(
-        bigquery_storage_v1beta1.BigQueryStorageClient
-    )
+    bqstorage_mock = mock.create_autospec(bigquery_storage_v1.BigQueryReadClient)
     bqstorage_instance_mock = mock.create_autospec(
-        bigquery_storage_v1beta1.BigQueryStorageClient, instance=True
+        bigquery_storage_v1.BigQueryReadClient, instance=True
     )
     bqstorage_instance_mock.transport = mock.Mock()
     bqstorage_mock.return_value = bqstorage_instance_mock
     bqstorage_client_patch = mock.patch(
-        "google.cloud.bigquery_storage_v1beta1.BigQueryStorageClient", bqstorage_mock
+        "google.cloud.bigquery_storage_v1.BigQueryReadClient", bqstorage_mock
     )
 
     table_id = "bigquery-public-data.samples.shakespeare"
@@ -895,7 +860,7 @@ def test_bigquery_magic_w_table_id_and_bqstorage_client():
     with default_patch, client_patch as client_mock, bqstorage_client_patch:
         client_mock().list_rows.return_value = row_iterator_mock
 
-        ip.run_cell_magic("bigquery", "--use_bqstorage_api --max_results=5", table_id)
+        ip.run_cell_magic("bigquery", "--max_results=5", table_id)
         row_iterator_mock.to_dataframe.assert_called_once_with(
             bqstorage_client=bqstorage_instance_mock
         )
